Crate kcr_work_karmada_io

Crate kcr_work_karmada_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the work.karmada.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

work.karmada.io/v1alpha1

  • ClusterResourceBinding
  • ResourceBinding
  • Work

work.karmada.io/v1alpha2

  • ClusterResourceBinding
  • ResourceBinding

Modules

v1alpha1
v1alpha2