This crate contains kube-rs compatible bindings for Kubernetes custom resources for the work.karmada.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
work.karmada.io/v1alpha1
ClusterResourceBindingResourceBindingWork
work.karmada.io/v1alpha2
ClusterResourceBindingResourceBinding